==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.zk));
        }
        set zj(a) {
            this.h(RateOfChangeAndMomentumIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = /*@__PURE__*/ markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        bj() {
            return new RateOfChangeAndMomentumIndicator();
        }
        get_abq() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.acc));
        }
        set acb(a) {
            this.h(RateOfChangeAndMomentumIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = /*@__PURE__*/ markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();
